.TH sane-mustek 5 "24 Jul 2000"
.IX sane-mustek
.SH NAME
sane-mustek - SANE backend for Mustek flatbed scanners
.SH DESCRIPTION
The
.B sane-mustek
library implements a SANE (Scanner Access Now Easy) backend that
provides access to Mustek (and some relabeled Trust) flatbed scanners.
At present, the following scanners are known to work more or less with
this backend:
.PP
.RS
Paragon MFS-6000CX
.br
Paragon MFS-12000CX
.br
Paragon MFC-600S, 600 II CD, ScanMagic 600 II SP 
.br
Paragon MFC-800S, 800 II SP
.br
Paragon MFS-6000SP
.br
Paragon MFS-8000SP
.br
Paragon MFS-1200SP, MFS-12000SP
.br
ScanExpress 6000SP
.br
ScanExpress 12000SP, 12000SP Plus, Paragon 1200 III SP, ScanMagic 9636S, 9636S Plus
.br
Paragon 1200 A3 Pro
.br
Paragon 600 II N
.br
Trust Imagery 1200 SP
.br
Trust Imagery 4800 SP
.br
Trust SCSI Connect 19200
.br
.RE
.PP
More details can be found on the Mustek backend homepage 
.IR http://hmg.home.pages.de/sane/.
.PP
Don't mix up MFS (Paragon), Pro and ScanExpress models! They're
completely different. Check the exact model name!
.PP
Note that most of the above scanners come with a SCSI interface.  The
only non-SCSI scanner that has some support at this point is the 600
II N scanner which comes with its own parallel port adapter (i.e., it
does
.I not
attach to the printer port).  More info on how to use the 600 II N can
be found below in section PARAGON 600 II N. Other parallel port
scanners are not supported by this backend but you may be successful
using the Mustek parallel port backend (mustek_pp). USB scanners are
not supported by this backend by now.
.PP
Mustek scanners have no protection against exceeding the physical scan
area height.  That is, if a scan is attempted with a height that
exceeds the height of the scan surface, the scanner begins making loud
noises and the scan mechanism may be damaged.  Thus, if you hear such
a noise, IMMEDIATELY turn off the scanner. This shouldn't happen if
your scanner is in the list of known scanners. There is more
information in the
.IR PROBLEMS
file.
.PP
If you own a Mustek (or Trust) scanner other than the ones listed
above that works with this backend, please let us know by sending the
scanner's exact model name (look at the front and back of the scanner)
and a debug output to
.IR sane\-devel@mostang.com .
You can get the debug output by setting the environment variable
SANE_DEBUG_MUSTEK to 5 and showing the list of available scanners with
scanimage \-L . Please send all of it to the mailing list.

.SH "DEVICE NAMES"
This backend expects device names of the form:
.PP
.RS
.I special
.RE
.PP
Where
.I special
is either the path-name for the special device that corresponds to a
SCSI scanner or the port number at which the 600 II N can
be found (see section PARAGON 600 II N below).  For SCSI
scanners, the special device name must be a generic SCSI device or a
symlink to such a device.  The program 
.IR find-scanner 
helps to find out the correct device. It can be found in the
.IR tools
directory of the SANE distribution. Under Linux, such a device name
could be
.I /dev/sga
or
.IR /dev/sge ,
for example.  See sane-scsi(5) for details.
.SH CONFIGURATION
The contents of the
.I mustek.conf
file is a list of options and device names that correspond to Mustek
scanners.  Empty lines and lines starting with a hash mark (#) are
ignored.  See sane-scsi(5) on details of what constitutes a valid
device name.
.PP
The four options supported are
.BR linedistance-fix ,
.BR lineart-fix ,
.BR buffersize ,
and
.BR strip-height .
Options come in two flavors: global and positional ones.  Global
options apply to all devices managed by the backend whereas positional
options apply just to the most recently mentioned device.  Note that
this means that the order in which the options appear matters!

Option
.B linedistance-fix
is positional and works around a problem that occurs with some SCSI
controllers (notably the ncr810 controller under Linux).  If color
scans have horizontal stripes and/or the colors are off, then it's
likely that your controller suffers from this problem.  Turning on
this option usually fixes the problem.

Option
.B lineart-fix
is positional and works around a timing problem that seems to exist
with certain MFS-12000SP scanners.  The problem manifests itself in
dropped lines when scanning in lineart mode.  Turning on this option
should fix the problem but may slow down scanning a bit.

Option
.B buffersize
is a positional option that overrides the default values set for scan 
buffers. The buffer size is specified in kilobytes. The default value
depends on the scanner type. Note that some ScanExpress scanners don't
like buffer sizes above 64 kb. If your sg driver can't set SCSI buffer
sizes at runtime you may have to change that value, too. See sane-scsi(5)
for details.

Finally,
.B strip-height
is a global option limits the maximum height of the strip scanned with
a single SCSI read command.  The height is specified in inches and may
contain a fractional part (e.g., 1.5).  Setting the strip-height to a
small value (one inch, for example) reduces the likelihood of
encountering problems with SCSI driver timeouts and/or timeouts with
other devices on the same SCSI bus.  Unfortunately, it also increases
scan times.  Thus, if the scanner is the only device on the SCSI bus
it is connected to and if it is known that the SCSI driver does not
suffer from premature timeouts, it is recommended to increase the
strip-height or remove the option completely, which corresponds to an
infinite strip height.  See sane-scsi(5) on how to avoid problems with
SCSI timeouts.
.PP
A sample configuration file is shown below:
.PP
.RS
# limit strip height of all scanners to 1.5 inches:
.br
option strip-height 1.5
.br

.br
/dev/scanner    # first Mustek scanner
.br
  # 1 MB buffer for /dev/scanner:
.br
  option buffersize 1024
.br
/dev/sge        # second Mustek scanner
.br
  # turn on fixes for /dev/sge:
.br
  option lineart-fix
.br
  option linedistance-fix
.RE

.SH SCSI ADAPTER TIPS
Mustek SCSI scanners are typically delivered with an ISA SCSI adapter.
Unfortunately, that adapter is not worth much since it is not
interrupt driven.  It is (sometimes) possible to get the supplied card
to work, but without interrupt line, scanning will be very slow and put
so much load on the system, that it becomes almost unusable for other tasks.
.PP
If you already have a working SCSI controller in your system, you
should consider that Mustek scanners do not support the SCSI-2
disconnect/reconnect protocol and hence tie up the SCSI bus while a
scan is in progress.  This means that no other SCSI device on the same
bus can be accessed while a scan is in progress.
.PP
Because the Mustek-supplied adapter is not worth much and because
Mustek scanners do not support the SCSI-2 disconnect/reconnect
protocol, it is recommended to install a separate (cheap) SCSI
controller for Mustek scanners.  For example, ncr810 based cards are
known to work fine and cost as little as fifty US dollars.
.PP
For Mustek scanners, it is typically necessary to configure the
low-level SCSI driver to disable synchronous transfers, tagged command
queuing, and target disconnects.  See sane\-scsi(5) for driver and
platform-specific information.
.PP
The ScanExpress models have sometimes trouble with high resolution
color mode. If you encounter sporadic corrupted images (parts duplicated
or shifted horizontally) kill all other applications before scanning
and (if sufficient memory is available) disable swapping. 

.SH PARAGON 600 II N
This backend has support for the Paragon 600 II N parallel port
scanner.  Note that this scanner comes with its own ISA card that
implements a funky parallel port (in other words, the scanner does not
connected to the printer parallel port).
.PP
This scanner can be configured by listing the port number
of the adapter in the mustek.conf file.  Valid port numbers are 0x26b,
0x2ab, 0x2eb, 0x22b, 0x32b, 0x36b, 0x3ab, 0x3eb.  Pick one that
doesn't conflict with the other hardware in your computer. Put only
one number on a single line. Example:

.IR 0x3eb

.PP
Note that for this scanner root privileges are required to access the
I/O ports.  Thus, either make frontends such as scanimage(1) and
xscanimage(1) setuid root (generally not recommended for safety
reasons) or, alternatively, access this backend through the network
daemon saned(1). On systems which support this feature, the scanner
can be accessed through
.IR /dev/port.
Don't forget to adjust the permissions for /dev/port. At least with
recent Linux kernels root privileges are necessary for /dev/port access,
too.
.PP
If your images have horizontal stripes in color mode, check option
linedistance-fix (see above). Apply this option for a scanner with
firmware version 2.x and disable it for version 1.x. 
.PP
Also note that after a while of no activity, some scanners themself (not
the SANE backend) turns off their CCFL lamps. This shutdown is not always
perfect with the result that the lamp sometimes continues to glow
dimly at one end. This doesn't appear to be dangerous since as soon as
you use the scanner again, the lamp turns back on to the normal high
brightness. However, the first image scanned after such a shutdown may
have stripes and appear to be over-exposed.  When this happens, just
take another scan, and the image will be fine.
.SH FILES
.TP
.I @CONFIGDIR@/mustek.conf
The backend configuration file (see also description of
.B SANE_CONFIG_DIR
below).
.TP
.I @LIBDIR@/libsane-mustek.a
The static library implementing this backend.
.TP
.I @LIBDIR@/libsane-mustek.so
The shared library implementing this backend (present on systems that
support dynamic loading).
.SH ENVIRONMENT
.TP
.B SANE_CONFIG_DIR
This environment variable specifies the list of directories that may
contain the configuration file.  Under UNIX, the directories are
separated by a colon (`:'), under OS/2, they are separated by a
semi-colon (`;').  If this variable is not set, the configuration file
is searched in two default directories: first, the current working
directory (".") and then in @CONFIGDIR@.  If the value of the
environment variable ends with the directory separator character, then
the default directories are searched after the explicitly specified
directories.  For example, setting
.B SANE_CONFIG_DIR
to "/tmp/config:" would result in directories "tmp/config", ".", and
"@CONFIGDIR@" being searched (in this order).
.TP
.B SANE_DEBUG_MUSTEK
If the library was compiled with debug support enabled, this
environment variable controls the debug level for this backend.  Higher
debug levels increase the verbosity of the output. 

.nf                                                                            
Value  Descsription
0      no output
1      print fatal errors
2      print important messages
3      print non-fatal errors and less important messages
4      print all but debugging messages
5      print everything

Example: 
export SANE_DEBUG_MUSTEK=4

.SH "SEE ALSO"
sane\-scsi(5)
.SH AUTHOR
David Mosberger and Andreas Czechanowski, SE extensions Andreas
Bolsch, bug fixes and Pro series extension Henning Meier-Geinitz
.SH BUGS
Scanning with the SCSI adapters supplied by Mustek is very slow at
high resolutions and wide scanareas. 

Only 1, 8 and 24 bit modes are supported.

Some scanners (e.g. Paragon 1200 A3 Pro) need more testing.

More detailed bug information is available at the Mustek backend
homepage
.IR http://hmg.home.pages.de/sane/ .

